Struct verifyKeychainAdminCall
pub struct verifyKeychainAdminCall {
pub account: Address,
pub hash: FixedBytes<32>,
pub signature: Bytes,
}Expand description
@notice Verifies whether a keychain signature was produced by a root or active admin key.
@param account The expected embedded root account
@param hash The message hash that was signed
@param signature The encoded keychain signature
@dev Does not compare the inner signature type against the stored key type.
@return True if the recovered key is account or an active admin key on account.
Function with signature verifyKeychainAdmin(address,bytes32,bytes) and selector 0x5f6fc5b7.
function verifyKeychainAdmin(address account, bytes32 hash, bytes calldata signature) external view returns (bool);Fields
account: Addresshash: FixedBytes<32>signature: BytesTrait Implementations
impl Clone for verifyKeychainAdminCall
impl Clone for verifyKeychainAdminCall
fn clone(&self) -> verifyKeychainAdminCall
fn clone(&self) -> verifyKeychainAdminCall
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for verifyKeychainAdminCall
impl Debug for verifyKeychainAdminCall
impl<'de> Deserialize<'de> for verifyKeychainAdminCall
impl<'de> Deserialize<'de> for verifyKeychainAdminCall
fn deserialize<__D>(
__deserializer: __D,
) -> Result<verifyKeychainAdminCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<verifyKeychainAdminCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for verifyKeychainAdminCall
impl JsonAbiExt for verifyKeychainAdminCall
impl JsonAbiExt for verifyKeychainAdminCall
fn abi() -> <verifyKeychainAdminCall as JsonAbiExt>::Abi
fn abi() -> <verifyKeychainAdminCall as JsonAbiExt>::Abi
impl PartialEq for verifyKeychainAdminCall
impl PartialEq for verifyKeychainAdminCall
fn eq(&self, other: &verifyKeychainAdminCall) -> bool
fn eq(&self, other: &verifyKeychainAdminCall) -> bool
self and other values to be equal, and is used by ==.impl Serialize for verifyKeychainAdminCall
impl Serialize for verifyKeychainAdminCall
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl SolCall for verifyKeychainAdminCall
impl SolCall for verifyKeychainAdminCall
const SIGNATURE: &'static str = "verifyKeychainAdmin(address,bytes32,bytes)"
const SIGNATURE: &'static str = "verifyKeychainAdmin(address,bytes32,bytes)"
type Parameters<'a> = (Address, FixedBytes<32>, Bytes)
type Parameters<'a> = (Address, FixedBytes<32>, Bytes)
type Token<'a> = <<verifyKeychainAdminCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<verifyKeychainAdminCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
type ReturnToken<'a> = <<verifyKeychainAdminCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<verifyKeychainAdminCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
fn new<'a>(
tuple: <<verifyKeychainAdminCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> verifyKeychainAdminCall
fn new<'a>( tuple: <<verifyKeychainAdminCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> verifyKeychainAdminCall
fn tokenize(&self) -> <verifyKeychainAdminCall as SolCall>::Token<'_>
fn tokenize(&self) -> <verifyKeychainAdminCall as SolCall>::Token<'_>
fn tokenize_returns(
ret: &<verifyKeychainAdminCall as SolCall>::Return,
) -> <verifyKeychainAdminCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<verifyKeychainAdminCall as SolCall>::Return, ) -> <verifyKeychainAdminCall as SolCall>::ReturnToken<'_>
fn abi_decode_returns(
data: &[u8],
) -> Result<<verifyKeychainAdminCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<verifyKeychainAdminCall as SolCall>::Return, Error>
fn abi_decode_returns_validate(
data: &[u8],
) -> Result<<verifyKeychainAdminCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<verifyKeychainAdminCall as SolCall>::Return, Error>
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
impl StructuralPartialEq for verifyKeychainAdminCall